"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuditLogsRequestBuilder = void 0;
const createAuditLogRootFromDiscriminatorValue_1 = require("../models/createAuditLogRootFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const directoryAuditsRequestBuilder_1 = require("./directoryAudits/directoryAuditsRequestBuilder");
const directoryAuditItemRequestBuilder_1 = require("./directoryAudits/item/directoryAuditItemRequestBuilder");
const provisioningObjectSummaryItemRequestBuilder_1 = require("./provisioning/item/provisioningObjectSummaryItemRequestBuilder");
const provisioningRequestBuilder_1 = require("./provisioning/provisioningRequestBuilder");
const restrictedSignInItemRequestBuilder_1 = require("./restrictedSignIns/item/restrictedSignInItemRequestBuilder");
const restrictedSignInsRequestBuilder_1 = require("./restrictedSignIns/restrictedSignInsRequestBuilder");
const signInItemRequestBuilder_1 = require("./signIns/item/signInItemRequestBuilder");
const signInsRequestBuilder_1 = require("./signIns/signInsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the auditLogRoot singleton.  */
class AuditLogsRequestBuilder {
    /**
     * Instantiates a new AuditLogsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/auditLogs{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The directoryAudits property  */
    get directoryAudits() {
        return new directoryAuditsRequestBuilder_1.DirectoryAuditsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The provisioning property  */
    get provisioning() {
        return new provisioningRequestBuilder_1.ProvisioningRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The restrictedSignIns property  */
    get restrictedSignIns() {
        return new restrictedSignInsRequestBuilder_1.RestrictedSignInsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The signIns property  */
    get signIns() {
        return new signInsRequestBuilder_1.SignInsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Get auditLogs
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters, headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (headers)
            requestInfo.headers = headers;
        queryParameters && requestInfo.setQueryStringParametersFromRawObject(queryParameters);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Update auditLogs
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, headers, options) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (headers)
            requestInfo.headers = headers;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.directoryAudits.item collection
     * @param id Unique identifier of the item
     * @returns a directoryAuditItemRequestBuilder
     */
    directoryAuditsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["directoryAudit%2Did"] = id;
        return new directoryAuditItemRequestBuilder_1.DirectoryAuditItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Get auditLogs
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AuditLogRoot
     */
    get(queryParameters, headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(queryParameters, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createAuditLogRootFromDiscriminatorValue_1.createAuditLogRootFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update auditLogs
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, headers, options, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.provisioning.item collection
     * @param id Unique identifier of the item
     * @returns a provisioningObjectSummaryItemRequestBuilder
     */
    provisioningById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["provisioningObjectSummary%2Did"] = id;
        return new provisioningObjectSummaryItemRequestBuilder_1.ProvisioningObjectSummaryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.restrictedSignIns.item collection
     * @param id Unique identifier of the item
     * @returns a restrictedSignInItemRequestBuilder
     */
    restrictedSignInsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["restrictedSignIn%2Did"] = id;
        return new restrictedSignInItemRequestBuilder_1.RestrictedSignInItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.signIns.item collection
     * @param id Unique identifier of the item
     * @returns a signInItemRequestBuilder
     */
    signInsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["signIn%2Did"] = id;
        return new signInItemRequestBuilder_1.SignInItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.AuditLogsRequestBuilder = AuditLogsRequestBuilder;
