import { OrganizationalBranding } from '../models/';
import { BackgroundImageRequestBuilder } from './backgroundImage/backgroundImageRequestBuilder';
import { BannerLogoRequestBuilder } from './bannerLogo/bannerLogoRequestBuilder';
import { BrandingRequestBuilderGetQueryParameters } from './brandingRequestBuilderGetQueryParameters';
import { OrganizationalBrandingLocalizationItemRequestBuilder } from './localizations/item/organizationalBrandingLocalizationItemRequestBuilder';
import { LocalizationsRequestBuilder } from './localizations/localizationsRequestBuilder';
import { SquareLogoRequestBuilder } from './squareLogo/squareLogoRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the organizationalBranding singleton.  */
export declare class BrandingRequestBuilder {
    /** The backgroundImage property  */
    get backgroundImage(): BackgroundImageRequestBuilder;
    /** The bannerLogo property  */
    get bannerLogo(): BannerLogoRequestBuilder;
    /** The localizations property  */
    get localizations(): LocalizationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The squareLogo property  */
    get squareLogo(): SquareLogoRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new BrandingRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get branding
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: BrandingRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update branding
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OrganizationalBranding | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get branding
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OrganizationalBranding
     */
    get(queryParameters?: BrandingRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<OrganizationalBranding | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.branding.localizations.item collection
     * @param id Unique identifier of the item
     * @returns a organizationalBrandingLocalizationItemRequestBuilder
     */
    localizationsById(id: string): OrganizationalBrandingLocalizationItemRequestBuilder;
    /**
     * Update branding
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OrganizationalBranding | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
