import { DeviceConfiguration } from '../../../models/';
import { AssignRequestBuilder } from './assign/assignRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { DeviceConfigurationAssignmentItemRequestBuilder } from './assignments/item/deviceConfigurationAssignmentItemRequestBuilder';
import { DeviceConfigurationItemRequestBuilderGetQueryParameters } from './deviceConfigurationItemRequestBuilderGetQueryParameters';
import { DeviceSettingStateSummariesRequestBuilder } from './deviceSettingStateSummaries/deviceSettingStateSummariesRequestBuilder';
import { SettingStateDeviceSummaryItemRequestBuilder } from './deviceSettingStateSummaries/item/settingStateDeviceSummaryItemRequestBuilder';
import { DeviceStatusesRequestBuilder } from './deviceStatuses/deviceStatusesRequestBuilder';
import { DeviceConfigurationDeviceStatusItemRequestBuilder } from './deviceStatuses/item/deviceConfigurationDeviceStatusItemRequestBuilder';
import { DeviceStatusOverviewRequestBuilder } from './deviceStatusOverview/deviceStatusOverviewRequestBuilder';
import { GetOmaSettingPlainTextValueWithSecretReferenceValueIdRequestBuilder } from './getOmaSettingPlainTextValueWithSecretReferenceValueId/getOmaSettingPlainTextValueWithSecretReferenceValueIdRequestBuilder';
import { DeviceConfigurationUserStatusItemRequestBuilder } from './userStatuses/item/deviceConfigurationUserStatusItemRequestBuilder';
import { UserStatusesRequestBuilder } from './userStatuses/userStatusesRequestBuilder';
import { UserStatusOverviewRequestBuilder } from './userStatusOverview/userStatusOverviewRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the deviceConfigurations property of the microsoft.graph.deviceManagement entity.  */
export declare class DeviceConfigurationItemRequestBuilder {
    /** The assign property  */
    get assign(): AssignRequestBuilder;
    /** The assignments property  */
    get assignments(): AssignmentsRequestBuilder;
    /** The deviceSettingStateSummaries property  */
    get deviceSettingStateSummaries(): DeviceSettingStateSummariesRequestBuilder;
    /** The deviceStatuses property  */
    get deviceStatuses(): DeviceStatusesRequestBuilder;
    /** The deviceStatusOverview property  */
    get deviceStatusOverview(): DeviceStatusOverviewRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /** The userStatuses property  */
    get userStatuses(): UserStatusesRequestBuilder;
    /** The userStatusOverview property  */
    get userStatusOverview(): UserStatusOverviewRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceConfigurations.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a deviceConfigurationAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): DeviceConfigurationAssignmentItemRequestBuilder;
    /**
     * Instantiates a new DeviceConfigurationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property deviceConfigurations for deviceManagement
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The device configurations.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: DeviceConfigurationItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property deviceConfigurations in deviceManagement
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DeviceConfiguration | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property deviceConfigurations for deviceManagement
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceConfigurations.item.deviceSettingStateSummaries.item collection
     * @param id Unique identifier of the item
     * @returns a settingStateDeviceSummaryItemRequestBuilder
     */
    deviceSettingStateSummariesById(id: string): SettingStateDeviceSummaryItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceConfigurations.item.deviceStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceConfigurationDeviceStatusItemRequestBuilder
     */
    deviceStatusesById(id: string): DeviceConfigurationDeviceStatusItemRequestBuilder;
    /**
     * The device configurations.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DeviceConfiguration
     */
    get(queryParameters?: DeviceConfigurationItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<DeviceConfiguration | undefined>;
    /**
     * Provides operations to call the getOmaSettingPlainTextValue method.
     * @param secretReferenceValueId Usage: secretReferenceValueId='{secretReferenceValueId}'
     * @returns a getOmaSettingPlainTextValueWithSecretReferenceValueIdRequestBuilder
     */
    getOmaSettingPlainTextValueWithSecretReferenceValueId(secretReferenceValueId: string | undefined): GetOmaSettingPlainTextValueWithSecretReferenceValueIdRequestBuilder;
    /**
     * Update the navigation property deviceConfigurations in deviceManagement
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DeviceConfiguration | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceConfigurations.item.userStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceConfigurationUserStatusItemRequestBuilder
     */
    userStatusesById(id: string): DeviceConfigurationUserStatusItemRequestBuilder;
}
