import { DriveItem } from '../../../../models/';
import { AnalyticsRequestBuilder } from './analytics/analyticsRequestBuilder';
import { ChildrenRequestBuilder } from './children/childrenRequestBuilder';
import { DriveItemItemRequestBuilder as i0f769c5b7a9fe0873034f07ccafbbeabb7d6ed3a467c8af9895b51955bb80320 } from './children/item/driveItemItemRequestBuilder';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { DriveItemItemRequestBuilderGetQueryParameters } from './driveItemItemRequestBuilderGetQueryParameters';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermissionItemRequestBuilder } from './permissions/item/permissionItemRequestBuilder';
import { PermissionsRequestBuilder } from './permissions/permissionsRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { ThumbnailSetItemRequestBuilder } from './thumbnails/item/thumbnailSetItemRequestBuilder';
import { ThumbnailsRequestBuilder } from './thumbnails/thumbnailsRequestBuilder';
import { DriveItemVersionItemRequestBuilder } from './versions/item/driveItemVersionItemRequestBuilder';
import { VersionsRequestBuilder } from './versions/versionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the items property of the microsoft.graph.drive entity.  */
export declare class DriveItemItemRequestBuilder {
    /** The analytics property  */
    get analytics(): AnalyticsRequestBuilder;
    /** The children property  */
    get children(): ChildrenRequestBuilder;
    /** The content property  */
    get content(): ContentRequestBuilder;
    /** The listItem property  */
    get listItem(): ListItemRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The permissions property  */
    get permissions(): PermissionsRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The subscriptions property  */
    get subscriptions(): SubscriptionsRequestBuilder;
    /** The thumbnails property  */
    get thumbnails(): ThumbnailsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /** The versions property  */
    get versions(): VersionsRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item.children.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    childrenById(id: string): i0f769c5b7a9fe0873034f07ccafbbeabb7d6ed3a467c8af9895b51955bb80320;
    /**
     * Instantiates a new DriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property items for drives
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: DriveItemItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property items in drives
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DriveItem | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property items for drives
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItem
     */
    get(queryParameters?: DriveItemItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<DriveItem | undefined>;
    /**
     * Update the navigation property items in drives
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DriveItem | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id: string): PermissionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item.thumbnails.item collection
     * @param id Unique identifier of the item
     * @returns a thumbnailSetItemRequestBuilder
     */
    thumbnailsById(id: string): ThumbnailSetItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item.versions.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemVersionItemRequestBuilder
     */
    versionsById(id: string): DriveItemVersionItemRequestBuilder;
}
