import { List } from '../../../../../../models/';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ColumnDefinitionItemRequestBuilder } from './columns/item/columnDefinitionItemRequestBuilder';
import { ContentTypesRequestBuilder } from './contentTypes/contentTypesRequestBuilder';
import { ContentTypeItemRequestBuilder } from './contentTypes/item/contentTypeItemRequestBuilder';
import { DriveRequestBuilder } from './drive/driveRequestBuilder';
import { ListItemItemRequestBuilder } from './items/item/listItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListItemRequestBuilderGetQueryParameters } from './listItemRequestBuilderGetQueryParameters';
import { RichLongRunningOperationItemRequestBuilder } from './operations/item/richLongRunningOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the lists property of the microsoft.graph.site entity.  */
export declare class ListItemRequestBuilder {
    /** The columns property  */
    get columns(): ColumnsRequestBuilder;
    /** The contentTypes property  */
    get contentTypes(): ContentTypesRequestBuilder;
    /** The drive property  */
    get drive(): DriveRequestBuilder;
    /** The items property  */
    get items(): ItemsRequestBuilder;
    /** The operations property  */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The subscriptions property  */
    get subscriptions(): SubscriptionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id: string): ColumnDefinitionItemRequestBuilder;
    /**
     * Instantiates a new ListItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id: string): ContentTypeItemRequestBuilder;
    /**
     * Delete navigation property lists for groups
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The collection of lists under this site.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: ListItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property lists in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: List | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property lists for groups
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The collection of lists under this site.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of List
     */
    get(queryParameters?: ListItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<List | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a listItemItemRequestBuilder
     */
    itemsById(id: string): ListItemItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a richLongRunningOperationItemRequestBuilder
     */
    operationsById(id: string): RichLongRunningOperationItemRequestBuilder;
    /**
     * Update the navigation property lists in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: List | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
}
