"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OnenoteRequestBuilder = void 0;
const createOnenoteFromDiscriminatorValue_1 = require("../../../../../models/createOnenoteFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const notebookItemRequestBuilder_1 = require("./notebooks/item/notebookItemRequestBuilder");
const notebooksRequestBuilder_1 = require("./notebooks/notebooksRequestBuilder");
const onenoteOperationItemRequestBuilder_1 = require("./operations/item/onenoteOperationItemRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const onenotePageItemRequestBuilder_1 = require("./pages/item/onenotePageItemRequestBuilder");
const pagesRequestBuilder_1 = require("./pages/pagesRequestBuilder");
const onenoteResourceItemRequestBuilder_1 = require("./resources/item/onenoteResourceItemRequestBuilder");
const resourcesRequestBuilder_1 = require("./resources/resourcesRequestBuilder");
const sectionGroupItemRequestBuilder_1 = require("./sectionGroups/item/sectionGroupItemRequestBuilder");
const sectionGroupsRequestBuilder_1 = require("./sectionGroups/sectionGroupsRequestBuilder");
const onenoteSectionItemRequestBuilder_1 = require("./sections/item/onenoteSectionItemRequestBuilder");
const sectionsRequestBuilder_1 = require("./sections/sectionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the onenote property of the microsoft.graph.site entity.  */
class OnenoteRequestBuilder {
    /**
     * Instantiates a new OnenoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/groups/{group%2Did}/sites/{site%2Did}/onenote{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The notebooks property  */
    get notebooks() {
        return new notebooksRequestBuilder_1.NotebooksRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The operations property  */
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The pages property  */
    get pages() {
        return new pagesRequestBuilder_1.PagesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The resources property  */
    get resources() {
        return new resourcesRequestBuilder_1.ResourcesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The sectionGroups property  */
    get sectionGroups() {
        return new sectionGroupsRequestBuilder_1.SectionGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The sections property  */
    get sections() {
        return new sectionsRequestBuilder_1.SectionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property onenote for groups
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (headers)
            requestInfo.headers = headers;
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters, headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (headers)
            requestInfo.headers = headers;
        queryParameters && requestInfo.setQueryStringParametersFromRawObject(queryParameters);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property onenote in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, headers, options) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (headers)
            requestInfo.headers = headers;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property onenote for groups
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Onenote
     */
    get(queryParameters, headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(queryParameters, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createOnenoteFromDiscriminatorValue_1.createOnenoteFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.notebooks.item collection
     * @param id Unique identifier of the item
     * @returns a notebookItemRequestBuilder
     */
    notebooksById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["notebook%2Did"] = id;
        return new notebookItemRequestBuilder_1.NotebookItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.operations.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteOperationItemRequestBuilder
     */
    operationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteOperation%2Did"] = id;
        return new onenoteOperationItemRequestBuilder_1.OnenoteOperationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.pages.item collection
     * @param id Unique identifier of the item
     * @returns a onenotePageItemRequestBuilder
     */
    pagesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenotePage%2Did"] = id;
        return new onenotePageItemRequestBuilder_1.OnenotePageItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property onenote in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, headers, options, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.resources.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteResourceItemRequestBuilder
     */
    resourcesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteResource%2Did"] = id;
        return new onenoteResourceItemRequestBuilder_1.OnenoteResourceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.sectionGroups.item collection
     * @param id Unique identifier of the item
     * @returns a sectionGroupItemRequestBuilder
     */
    sectionGroupsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["sectionGroup%2Did"] = id;
        return new sectionGroupItemRequestBuilder_1.SectionGroupItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.onenote.sections.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteSectionItemRequestBuilder
     */
    sectionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteSection%2Did"] = id;
        return new onenoteSectionItemRequestBuilder_1.OnenoteSectionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.OnenoteRequestBuilder = OnenoteRequestBuilder;
