"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrimaryChannelRequestBuilder = void 0;
const createChannelFromDiscriminatorValue_1 = require("../../../../models/createChannelFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const completeMigrationRequestBuilder_1 = require("./completeMigration/completeMigrationRequestBuilder");
const filesFolderRequestBuilder_1 = require("./filesFolder/filesFolderRequestBuilder");
const conversationMemberItemRequestBuilder_1 = require("./members/item/conversationMemberItemRequestBuilder");
const membersRequestBuilder_1 = require("./members/membersRequestBuilder");
const chatMessageItemRequestBuilder_1 = require("./messages/item/chatMessageItemRequestBuilder");
const messagesRequestBuilder_1 = require("./messages/messagesRequestBuilder");
const provisionEmailRequestBuilder_1 = require("./provisionEmail/provisionEmailRequestBuilder");
const removeEmailRequestBuilder_1 = require("./removeEmail/removeEmailRequestBuilder");
const teamsTabItemRequestBuilder_1 = require("./tabs/item/teamsTabItemRequestBuilder");
const tabsRequestBuilder_1 = require("./tabs/tabsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.  */
class PrimaryChannelRequestBuilder {
    /**
     * Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/groups/{group%2Did}/team/primaryChannel{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The completeMigration property  */
    get completeMigration() {
        return new completeMigrationRequestBuilder_1.CompleteMigrationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The filesFolder property  */
    get filesFolder() {
        return new filesFolderRequestBuilder_1.FilesFolderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The members property  */
    get members() {
        return new membersRequestBuilder_1.MembersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The messages property  */
    get messages() {
        return new messagesRequestBuilder_1.MessagesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The provisionEmail property  */
    get provisionEmail() {
        return new provisionEmailRequestBuilder_1.ProvisionEmailRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The removeEmail property  */
    get removeEmail() {
        return new removeEmailRequestBuilder_1.RemoveEmailRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The tabs property  */
    get tabs() {
        return new tabsRequestBuilder_1.TabsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property primaryChannel for groups
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (headers)
            requestInfo.headers = headers;
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * The general channel for the team.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters, headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (headers)
            requestInfo.headers = headers;
        queryParameters && requestInfo.setQueryStringParametersFromRawObject(queryParameters);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property primaryChannel in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, headers, options) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (headers)
            requestInfo.headers = headers;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property primaryChannel for groups
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The general channel for the team.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Channel
     */
    get(queryParameters, headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(queryParameters, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createChannelFromDiscriminatorValue_1.createChannelFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.primaryChannel.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["conversationMember%2Did"] = id;
        return new conversationMemberItemRequestBuilder_1.ConversationMemberItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.primaryChannel.messages.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageItemRequestBuilder
     */
    messagesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["chatMessage%2Did"] = id;
        return new chatMessageItemRequestBuilder_1.ChatMessageItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property primaryChannel in groups
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, headers, options, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.primaryChannel.tabs.item collection
     * @param id Unique identifier of the item
     * @returns a teamsTabItemRequestBuilder
     */
    tabsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["teamsTab%2Did"] = id;
        return new teamsTabItemRequestBuilder_1.TeamsTabItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.PrimaryChannelRequestBuilder = PrimaryChannelRequestBuilder;
