import { Channel } from '../../../../../models/';
import { ChannelItemRequestBuilderGetQueryParameters } from './channelItemRequestBuilderGetQueryParameters';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { FilesFolderRequestBuilder } from './filesFolder/filesFolderRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { ChatMessageItemRequestBuilder } from './messages/item/chatMessageItemRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { ProvisionEmailRequestBuilder } from './provisionEmail/provisionEmailRequestBuilder';
import { RemoveEmailRequestBuilder } from './removeEmail/removeEmailRequestBuilder';
import { TeamsTabItemRequestBuilder } from './tabs/item/teamsTabItemRequestBuilder';
import { TabsRequestBuilder } from './tabs/tabsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the channels property of the microsoft.graph.team entity.  */
export declare class ChannelItemRequestBuilder {
    /** The completeMigration property  */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /** The filesFolder property  */
    get filesFolder(): FilesFolderRequestBuilder;
    /** The members property  */
    get members(): MembersRequestBuilder;
    /** The messages property  */
    get messages(): MessagesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The provisionEmail property  */
    get provisionEmail(): ProvisionEmailRequestBuilder;
    /** The removeEmail property  */
    get removeEmail(): RemoveEmailRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The tabs property  */
    get tabs(): TabsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new ChannelItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property channels for me
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The collection of channels and messages associated with the team.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: ChannelItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property channels in me
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Channel | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property channels for me
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The collection of channels and messages associated with the team.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Channel
     */
    get(queryParameters?: ChannelItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Channel | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.channels.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.channels.item.messages.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageItemRequestBuilder
     */
    messagesById(id: string): ChatMessageItemRequestBuilder;
    /**
     * Update the navigation property channels in me
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Channel | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.channels.item.tabs.item collection
     * @param id Unique identifier of the item
     * @returns a teamsTabItemRequestBuilder
     */
    tabsById(id: string): TeamsTabItemRequestBuilder;
}
