import { Planner } from '../models/';
import { BucketsRequestBuilder } from './buckets/bucketsRequestBuilder';
import { PlannerBucketItemRequestBuilder } from './buckets/item/plannerBucketItemRequestBuilder';
import { PlannerRequestBuilderGetQueryParameters } from './plannerRequestBuilderGetQueryParameters';
import { PlannerPlanItemRequestBuilder } from './plans/item/plannerPlanItemRequestBuilder';
import { PlansRequestBuilder } from './plans/plansRequestBuilder';
import { PlannerTaskItemRequestBuilder } from './tasks/item/plannerTaskItemRequestBuilder';
import { TasksRequestBuilder } from './tasks/tasksRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the planner singleton.  */
export declare class PlannerRequestBuilder {
    /** The buckets property  */
    get buckets(): BucketsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The plans property  */
    get plans(): PlansRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The tasks property  */
    get tasks(): TasksRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.buckets.item collection
     * @param id Unique identifier of the item
     * @returns a plannerBucketItemRequestBuilder
     */
    bucketsById(id: string): PlannerBucketItemRequestBuilder;
    /**
     * Instantiates a new PlannerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get planner
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: PlannerRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update planner
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Planner | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get planner
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Planner
     */
    get(queryParameters?: PlannerRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Planner | undefined>;
    /**
     * Update planner
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Planner | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.plans.item collection
     * @param id Unique identifier of the item
     * @returns a plannerPlanItemRequestBuilder
     */
    plansById(id: string): PlannerPlanItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.tasks.item collection
     * @param id Unique identifier of the item
     * @returns a plannerTaskItemRequestBuilder
     */
    tasksById(id: string): PlannerTaskItemRequestBuilder;
}
