"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlannerRequestBuilder = void 0;
const createPlannerFromDiscriminatorValue_1 = require("../models/createPlannerFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const bucketsRequestBuilder_1 = require("./buckets/bucketsRequestBuilder");
const plannerBucketItemRequestBuilder_1 = require("./buckets/item/plannerBucketItemRequestBuilder");
const plannerPlanItemRequestBuilder_1 = require("./plans/item/plannerPlanItemRequestBuilder");
const plansRequestBuilder_1 = require("./plans/plansRequestBuilder");
const plannerTaskItemRequestBuilder_1 = require("./tasks/item/plannerTaskItemRequestBuilder");
const tasksRequestBuilder_1 = require("./tasks/tasksRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the planner singleton.  */
class PlannerRequestBuilder {
    /**
     * Instantiates a new PlannerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/planner{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The buckets property  */
    get buckets() {
        return new bucketsRequestBuilder_1.BucketsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The plans property  */
    get plans() {
        return new plansRequestBuilder_1.PlansRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The tasks property  */
    get tasks() {
        return new tasksRequestBuilder_1.TasksRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.buckets.item collection
     * @param id Unique identifier of the item
     * @returns a plannerBucketItemRequestBuilder
     */
    bucketsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["plannerBucket%2Did"] = id;
        return new plannerBucketItemRequestBuilder_1.PlannerBucketItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Get planner
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters, headers, options) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (headers)
            requestInfo.headers = headers;
        queryParameters && requestInfo.setQueryStringParametersFromRawObject(queryParameters);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Update planner
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, headers, options) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (headers)
            requestInfo.headers = headers;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        options && requestInfo.addRequestOptions(...options);
        return requestInfo;
    }
    ;
    /**
     * Get planner
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Planner
     */
    get(queryParameters, headers, options, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(queryParameters, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createPlannerFromDiscriminatorValue_1.createPlannerFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update planner
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, headers, options, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, headers, options);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.plans.item collection
     * @param id Unique identifier of the item
     * @returns a plannerPlanItemRequestBuilder
     */
    plansById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["plannerPlan%2Did"] = id;
        return new plannerPlanItemRequestBuilder_1.PlannerPlanItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.planner.tasks.item collection
     * @param id Unique identifier of the item
     * @returns a plannerTaskItemRequestBuilder
     */
    tasksById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["plannerTask%2Did"] = id;
        return new plannerTaskItemRequestBuilder_1.PlannerTaskItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.PlannerRequestBuilder = PlannerRequestBuilder;
