import { Printer } from '../../../models/';
import { ConnectorsRequestBuilder } from './connectors/connectorsRequestBuilder';
import { PrintConnectorItemRequestBuilder } from './connectors/item/printConnectorItemRequestBuilder';
import { PrinterItemRequestBuilderGetQueryParameters } from './printerItemRequestBuilderGetQueryParameters';
import { RestoreFactoryDefaultsRequestBuilder } from './restoreFactoryDefaults/restoreFactoryDefaultsRequestBuilder';
import { PrinterShareItemRequestBuilder } from './shares/item/printerShareItemRequestBuilder';
import { SharesRequestBuilder } from './shares/sharesRequestBuilder';
import { PrintTaskTriggerItemRequestBuilder } from './taskTriggers/item/printTaskTriggerItemRequestBuilder';
import { TaskTriggersRequestBuilder } from './taskTriggers/taskTriggersRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the printers property of the microsoft.graph.print entity.  */
export declare class PrinterItemRequestBuilder {
    /** The connectors property  */
    get connectors(): ConnectorsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The restoreFactoryDefaults property  */
    get restoreFactoryDefaults(): RestoreFactoryDefaultsRequestBuilder;
    /** The shares property  */
    get shares(): SharesRequestBuilder;
    /** The taskTriggers property  */
    get taskTriggers(): TaskTriggersRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.printers.item.connectors.item collection
     * @param id Unique identifier of the item
     * @returns a printConnectorItemRequestBuilder
     */
    connectorsById(id: string): PrintConnectorItemRequestBuilder;
    /**
     * Instantiates a new PrinterItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property printers for print
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The list of printers registered in the tenant.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: PrinterItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property printers in print
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Printer | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property printers for print
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The list of printers registered in the tenant.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Printer
     */
    get(queryParameters?: PrinterItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Printer | undefined>;
    /**
     * Update the navigation property printers in print
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Printer | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.printers.item.shares.item collection
     * @param id Unique identifier of the item
     * @returns a printerShareItemRequestBuilder
     */
    sharesById(id: string): PrinterShareItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.printers.item.taskTriggers.item collection
     * @param id Unique identifier of the item
     * @returns a printTaskTriggerItemRequestBuilder
     */
    taskTriggersById(id: string): PrintTaskTriggerItemRequestBuilder;
}
