import { SharedDriveItem } from '../../models/';
import { DriveItemRequestBuilder } from './driveItem/driveItemRequestBuilder';
import { DriveItemItemRequestBuilder } from './items/item/driveItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListRequestBuilder } from './list/listRequestBuilder';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermissionRequestBuilder } from './permission/permissionRequestBuilder';
import { RootRequestBuilder } from './root/rootRequestBuilder';
import { SharedDriveItemItemRequestBuilderGetQueryParameters } from './sharedDriveItemItemRequestBuilderGetQueryParameters';
import { SiteRequestBuilder } from './site/siteRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of sharedDriveItem entities.  */
export declare class SharedDriveItemItemRequestBuilder {
    /** The driveItem property  */
    get driveItem(): DriveItemRequestBuilder;
    /** The items property  */
    get items(): ItemsRequestBuilder;
    /** The list property  */
    get list(): ListRequestBuilder;
    /** The listItem property  */
    get listItem(): ListItemRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The permission property  */
    get permission(): PermissionRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The root property  */
    get root(): RootRequestBuilder;
    /** The site property  */
    get site(): SiteRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new SharedDriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from shares
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from shares by key
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: SharedDriveItemItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in shares
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SharedDriveItem | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from shares
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get entity from shares by key
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SharedDriveItem
     */
    get(queryParameters?: SharedDriveItemItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<SharedDriveItem | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.shares.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    itemsById(id: string): DriveItemItemRequestBuilder;
    /**
     * Update entity in shares
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SharedDriveItem | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
