import { SolutionsRoot } from '../models/';
import { BookingBusinessesRequestBuilder } from './bookingBusinesses/bookingBusinessesRequestBuilder';
import { BookingBusinessItemRequestBuilder } from './bookingBusinesses/item/bookingBusinessItemRequestBuilder';
import { BookingCurrenciesRequestBuilder } from './bookingCurrencies/bookingCurrenciesRequestBuilder';
import { BookingCurrencyItemRequestBuilder } from './bookingCurrencies/item/bookingCurrencyItemRequestBuilder';
import { SolutionsRequestBuilderGetQueryParameters } from './solutionsRequestBuilderGetQueryParameters';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the solutionsRoot singleton.  */
export declare class SolutionsRequestBuilder {
    /** The bookingBusinesses property  */
    get bookingBusinesses(): BookingBusinessesRequestBuilder;
    /** The bookingCurrencies property  */
    get bookingCurrencies(): BookingCurrenciesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item collection
     * @param id Unique identifier of the item
     * @returns a bookingBusinessItemRequestBuilder
     */
    bookingBusinessesById(id: string): BookingBusinessItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingCurrencies.item collection
     * @param id Unique identifier of the item
     * @returns a bookingCurrencyItemRequestBuilder
     */
    bookingCurrenciesById(id: string): BookingCurrencyItemRequestBuilder;
    /**
     * Instantiates a new SolutionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get solutions
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: SolutionsRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update solutions
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SolutionsRoot | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get solutions
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SolutionsRoot
     */
    get(queryParameters?: SolutionsRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<SolutionsRoot | undefined>;
    /**
     * Update solutions
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SolutionsRoot | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
