import { Team } from '../../models/';
import { ArchiveRequestBuilder } from './archive/archiveRequestBuilder';
import { ChannelsRequestBuilder } from './channels/channelsRequestBuilder';
import { ChannelItemRequestBuilder } from './channels/item/channelItemRequestBuilder';
import { CloneRequestBuilder } from './clone/cloneRequestBuilder';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { TeamsAppInstallationItemRequestBuilder } from './installedApps/item/teamsAppInstallationItemRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { TeamsAsyncOperationItemRequestBuilder } from './operations/item/teamsAsyncOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrimaryChannelRequestBuilder } from './primaryChannel/primaryChannelRequestBuilder';
import { ScheduleRequestBuilder } from './schedule/scheduleRequestBuilder';
import { SendActivityNotificationRequestBuilder } from './sendActivityNotification/sendActivityNotificationRequestBuilder';
import { TeamItemRequestBuilderGetQueryParameters } from './teamItemRequestBuilderGetQueryParameters';
import { TemplateRequestBuilder } from './template/templateRequestBuilder';
import { UnarchiveRequestBuilder } from './unarchive/unarchiveRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of team entities.  */
export declare class TeamItemRequestBuilder {
    /** The archive property  */
    get archive(): ArchiveRequestBuilder;
    /** The channels property  */
    get channels(): ChannelsRequestBuilder;
    /** The clone property  */
    get clone(): CloneRequestBuilder;
    /** The completeMigration property  */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /** The group property  */
    get group(): GroupRequestBuilder;
    /** The installedApps property  */
    get installedApps(): InstalledAppsRequestBuilder;
    /** The members property  */
    get members(): MembersRequestBuilder;
    /** The operations property  */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The primaryChannel property  */
    get primaryChannel(): PrimaryChannelRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** The schedule property  */
    get schedule(): ScheduleRequestBuilder;
    /** The sendActivityNotification property  */
    get sendActivityNotification(): SendActivityNotificationRequestBuilder;
    /** The template property  */
    get template(): TemplateRequestBuilder;
    /** The unarchive property  */
    get unarchive(): UnarchiveRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.channels.item collection
     * @param id Unique identifier of the item
     * @returns a channelItemRequestBuilder
     */
    channelsById(id: string): ChannelItemRequestBuilder;
    /**
     * Instantiates a new TeamItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from teams
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from teams by key
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: TeamItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in teams
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Team | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from teams
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get entity from teams by key
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    get(queryParameters?: TeamItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Team | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id: string): TeamsAppInstallationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAsyncOperationItemRequestBuilder
     */
    operationsById(id: string): TeamsAsyncOperationItemRequestBuilder;
    /**
     * Update entity in teams
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Team | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
