import { Notebook, NotebookCollectionResponse } from '../../../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { GetNotebookFromWebUrlRequestBuilder } from './getNotebookFromWebUrl/getNotebookFromWebUrlRequestBuilder';
import { GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder } from './getRecentNotebooksWithIncludePersonalNotebooks/getRecentNotebooksWithIncludePersonalNotebooksRequestBuilder';
import { NotebooksRequestBuilderGetQueryParameters } from './notebooksRequestBuilderGetQueryParameters';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the notebooks property of the microsoft.graph.onenote entity.  */
export declare class NotebooksRequestBuilder {
    /** The count property  */
    get count(): CountRequestBuilder;
    /** The getNotebookFromWebUrl property  */
    get getNotebookFromWebUrl(): GetNotebookFromWebUrlRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new NotebooksRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: NotebooksRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Create new navigation property to notebooks for users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: Notebook | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of NotebookCollectionResponse
     */
    get(queryParameters?: NotebooksRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<NotebookCollectionResponse | undefined>;
    /**
     * Provides operations to call the getRecentNotebooks method.
     * @param includePersonalNotebooks Usage: includePersonalNotebooks={includePersonalNotebooks}
     * @returns a getRecentNotebooksWithIncludePersonalNotebooksRequestBuilder
     */
    getRecentNotebooksWithIncludePersonalNotebooks(includePersonalNotebooks: boolean | undefined): GetRecentNotebooksWithIncludePersonalNotebooksRequestBuilder;
    /**
     * Create new navigation property to notebooks for users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Notebook
     */
    post(body: Notebook | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Notebook | undefined>;
}
