import { OnenotePage } from '../../../../../models/';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { CopyToSectionRequestBuilder } from './copyToSection/copyToSectionRequestBuilder';
import { OnenotePageItemRequestBuilderGetQueryParameters } from './onenotePageItemRequestBuilderGetQueryParameters';
import { OnenotePatchContentRequestBuilder } from './onenotePatchContent/onenotePatchContentRequestBuilder';
import { ParentNotebookRequestBuilder } from './parentNotebook/parentNotebookRequestBuilder';
import { ParentSectionRequestBuilder } from './parentSection/parentSectionRequestBuilder';
import { PreviewRequestBuilder } from './preview/previewRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the pages property of the microsoft.graph.onenote entity.  */
export declare class OnenotePageItemRequestBuilder {
    /** The content property  */
    get content(): ContentRequestBuilder;
    /** The copyToSection property  */
    get copyToSection(): CopyToSectionRequestBuilder;
    /** The onenotePatchContent property  */
    get onenotePatchContent(): OnenotePatchContentRequestBuilder;
    /** The parentNotebook property  */
    get parentNotebook(): ParentNotebookRequestBuilder;
    /** The parentSection property  */
    get parentSection(): ParentSectionRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new OnenotePageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property pages for users
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * The pages in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: OnenotePageItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property pages in users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OnenotePage | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property pages for users
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The pages in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OnenotePage
     */
    get(queryParameters?: OnenotePageItemRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<OnenotePage | undefined>;
    /**
     * Update the navigation property pages in users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OnenotePage | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the preview method.
     * @returns a previewRequestBuilder
     */
    preview(): PreviewRequestBuilder;
}
