import { OutlookUser } from '../../../models/';
import { OutlookCategoryItemRequestBuilder } from './masterCategories/item/outlookCategoryItemRequestBuilder';
import { MasterCategoriesRequestBuilder } from './masterCategories/masterCategoriesRequestBuilder';
import { OutlookRequestBuilderGetQueryParameters } from './outlookRequestBuilderGetQueryParameters';
import { SupportedLanguagesRequestBuilder } from './supportedLanguages/supportedLanguagesRequestBuilder';
import { SupportedTimeZonesRequestBuilder } from './supportedTimeZones/supportedTimeZonesRequestBuilder';
import { SupportedTimeZonesWithTimeZoneStandardRequestBuilder } from './supportedTimeZonesWithTimeZoneStandard/supportedTimeZonesWithTimeZoneStandardRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the outlook property of the microsoft.graph.user entity.  */
export declare class OutlookRequestBuilder {
    /** The masterCategories property  */
    get masterCategories(): MasterCategoriesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new OutlookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property outlook for users
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Read-only.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(queryParameters?: OutlookRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property outlook in users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OutlookUser | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property outlook for users
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Read-only.
     * @param headers Request headers
     * @param options Request options
     * @param queryParameters Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OutlookUser
     */
    get(queryParameters?: OutlookRequestBuilderGetQueryParameters | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<OutlookUser | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.outlook.masterCategories.item collection
     * @param id Unique identifier of the item
     * @returns a outlookCategoryItemRequestBuilder
     */
    masterCategoriesById(id: string): OutlookCategoryItemRequestBuilder;
    /**
     * Update the navigation property outlook in users
     * @param body
     * @param headers Request headers
     * @param options Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OutlookUser | undefined, headers?: Record<string, string> | undefined, options?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the supportedLanguages method.
     * @returns a supportedLanguagesRequestBuilder
     */
    supportedLanguages(): SupportedLanguagesRequestBuilder;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @returns a supportedTimeZonesRequestBuilder
     */
    supportedTimeZones(): SupportedTimeZonesRequestBuilder;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @param TimeZoneStandard Usage: TimeZoneStandard='{TimeZoneStandard}'
     * @returns a supportedTimeZonesWithTimeZoneStandardRequestBuilder
     */
    supportedTimeZonesWithTimeZoneStandard(timeZoneStandard: string | undefined): SupportedTimeZonesWithTimeZoneStandardRequestBuilder;
}
